/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.annotation.processor;

/**
 * The job of an {@link IAnnotationProcessor} is to traverse all
 * the annotations it can find on a given Object/Class.
 * For each found annotation, it will call an {@link IAnnotationHandler}
 * that know how to deal with this particular annotation.
 * @author Guillaume Sauthier
 */
public interface IAnnotationProcessor {

	/**
	 * Process the given object.
	 * @param target processed object
	 * @throws ProcessorException
	 */
	void process(Object target) throws ProcessorException;

	/**
	 * Process the given class and uses the given target
	 * instance for injection if any.
	 * @param target Object for injection
	 * @param clazz Class to be processed
	 * @throws ProcessorException
	 */
	void process(Object target, Class<?> clazz) throws ProcessorException;

	/**
	 * Register the given handler
	 * @param handler registered handler
	 */
	void addAnnotationHandler(IAnnotationHandler handler);

	/**
	 * Unregister the given handler
	 * @param handler unregistered handler
	 */
	void removeAnnotationHandler(IAnnotationHandler handler);
}
