/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.annotation.processor.handler;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.lang.reflect.Method;

import org.ow2.util.annotation.processor.IAnnotationHandler;
import org.ow2.util.annotation.processor.ProcessorException;

/**
 * An {@link AbstractAnnotationHandler} a facility class that provides
 * no-op implementation of the methods of {@link IAnnotationHandler}.
 *
 * @author Guillaume Sauthier
 */
public abstract class AbstractAnnotationHandler implements IAnnotationHandler {


    public void process(final Annotation annotation,
                        final Class<?> clazz,
                        final Object target) throws ProcessorException {
        // No-op
    }

    public void process(final Annotation annotation,
                        final Method method,
                        final Object target) throws ProcessorException {
        // No-op
    }

    public void process(final Annotation annotation,
                        final Field field,
                        final Object target) throws ProcessorException {
        // No-op
    }
}
